@@ -1,7 +1,6 @@
 import tkinter as tk
 import math
 import numpy as np
-from .utils import normalize_color, generate_edges_from_faces, load_obj, create_cube as create_cube_data, create_object_from_file as create_object_from_file_base
 
 class Point3D:
     """Класс для представления 3D точки."""
@@ -30,9 +29,9 @@ class Object3D:
         self.speed_x = speed_x if speed_x is not None else speed  # Скорость вращения по X
         self.speed_y = speed_y if speed_y is not None else speed  # Скорость вращения по Y
         self.speed_z = speed_z if speed_z is not None else speed  # Скорость вращения по Z
-        self.color = normalize_color(color)  # Нормализуем цвет
+        self.color = color  # Цвет заливки граней
         self.fill = fill  # Флаг заливки граней
-        self.outline_color = normalize_color(outline_color)  # Нормализуем цвет контура
+        self.outline_color = outline_color  # Цвет контура
         self.line_width = line_width  # Толщина линий рёбер
 
     def set_position(self, x, y, z):
@@ -92,15 +91,12 @@ class Object3D:
 
 class Scene3D:
     """Класс для управления 3D сценой."""
-    def __init__(self, width=600, height=600, title="3D Сцена", bg="black", master=None):
+    def __init__(self, width=600, height=600, title="3D Сцена", bg="black"):
         self.width = width
         self.height = height
         self.scale = 200
         self.objects = []
-        if master:
-            self.window = master  # Use provided master window (e.g., Toplevel)
-        else:
-            self.window = tk.Tk()  # Create new root window
+        self.window = tk.Tk()
         self.window.title(title)
         self.canvas = tk.Canvas(self.window, width=width, height=height, bg=bg)
         self.canvas.pack()
@@ -133,8 +129,8 @@ class Scene3D:
                     # Сохраняем все нужные свойства для отрисовки
                     render_properties = {
                         "is_filled": obj.fill,
-                        "fill_color": self._color_to_hex(obj.color),
-                        "outline_color": self._color_to_hex(obj.outline_color),
+                        "fill_color": obj.color,
+                        "outline_color": obj.outline_color,
                         "line_width": obj.line_width
                     }
                     polygons.append((z_avg, points_2d, render_properties))
@@ -151,13 +147,10 @@ class Scene3D:
             for edge in obj.edges:
                 p1 = projected_points[edge[0]]
                 p2 = projected_points[edge[1]]
-                self.canvas.create_line(p1[0], p1[1], p2[0], p2[1], fill=self._color_to_hex(obj.outline_color), width=obj.line_width)
+                self.canvas.create_line(p1[0], p1[1], p2[0], p2[1], fill=obj.outline_color, width=obj.line_width)
         self.window.after(16, self.update)  # ~60 FPS
 
-    def _color_to_hex(self, color):
-        """Конвертирует нормализованный цвет (0-1) в hex для Tkinter."""
-        r, g, b = int(color[0] * 255), int(color[1] * 255), int(color[2] * 255)
-        return f'#{r:02x}{g:02x}{b:02x}'
+
 
     def on_key_press(self, event):
         """Обработка нажатий клавиш для управления игроком."""
@@ -186,13 +179,90 @@ class Scene3D:
         self.window.mainloop()
 
 def create_cube(size=150, speed=0.01, position=(0, 0, 0), color="white", fill=False, outline_color="white", line_width=2, speed_x=None, speed_y=None, speed_z=None):
-    """Создаёт куб с заданными параметрами."""
-    points, edges, faces = create_cube_data(size)
+    """Создаёт куб с заданными параметрами: размер, скорость вращения, позиция, цвет заливки, флаг заливки, цвет контура."""
+    points = [
+        [-size, -size, -size],
+        [ size, -size, -size],
+        [ size,  size, -size],
+        [-size,  size, -size],
+        [-size, -size,  size],
+        [ size, -size,  size],
+        [ size,  size,  size],
+        [-size,  size,  size]
+    ]
+    edges = [
+        (0, 1), (1, 2), (2, 3), (3, 0),
+        (4, 5), (5, 6), (6, 7), (7, 4),
+        (0, 4), (1, 5), (2, 6), (3, 7)
+    ]
+    faces = [
+        (0, 1, 2, 3),  # Задняя грань
+        (4, 5, 6, 7),  # Передняя грань
+        (0, 4, 7, 3),  # Левая грань
+        (1, 5, 6, 2),  # Правая грань
+        (0, 1, 5, 4),  # Нижняя грань
+        (3, 2, 6, 7)   # Верхняя грань
+    ]
     return Object3D(points, edges, faces, speed, position, color, fill, outline_color, line_width, speed_x, speed_y, speed_z)
 
+def generate_edges_from_faces(faces):
+    """Создаёт уникальный список рёбер из списка граней."""
+    edges = set()
+    for face in faces:
+        # Для каждой грани создаем рёбра между соседними вершинами
+        for i in range(len(face)):
+            p1_index = face[i]
+            p2_index = face[(i + 1) % len(face)]  # Следующая вершина с переходом в начало
+
+            # Добавляем ребро в set, чтобы избежать дубликатов.
+            # Сортируем индексы, чтобы (0, 1) и (1, 0) считались одним и тем же ребром.
+            edge = tuple(sorted((p1_index, p2_index)))
+            edges.add(edge)
+
+    return list(edges)
+
+def load_obj(filename):
+    """Загружает 3D модель из .obj файла и возвращает списки точек и граней."""
+    points = []
+    faces = []
+
+    with open(filename, 'r') as file:
+        for line in file:
+            line = line.strip()
+            if not line or line.startswith('#'):
+                continue
+            parts = line.split()
+            if not parts:
+                continue
+
+            if parts[0] == 'v':
+                # Вершина: v x y z
+                if len(parts) >= 4:
+                    x, y, z = float(parts[1]), float(parts[2]), float(parts[3])
+                    points.append([x, y, z])
+            elif parts[0] == 'f':
+                # Грань: f v1 v2 v3 ...
+                face_indices = []
+                for part in parts[1:]:
+                    # Разбираем индексы вершин (могут быть в формате v/vt/vn)
+                    vertex_index = part.split('/')[0]
+                    if vertex_index.isdigit():
+                        face_indices.append(int(vertex_index) - 1)  # OBJ использует 1-based индексы
+                if len(face_indices) >= 3:
+                    faces.append(tuple(face_indices))
+
+    return points, faces
+
 def create_object_from_file(filename, **options):
     """Загружает модель из .obj и создает полностью готовый Object3D."""
-    return create_object_from_file_base(filename, **options)
+    points, faces = load_obj(filename)
+    if not points or not faces:
+        return None  # Возвращаем None, если файл пуст или некорректен
+
+    edges = generate_edges_from_faces(faces)
+
+    # Создаем объект, передавая ему и грани, и сгенерированные рёбра
+    return Object3D(points, edges=edges, faces=faces, **options)
 
 def quick_scene(*objects, width=600, height=600, title="3D Сцена", bg="black"):
     """Быстро создаёт сцену с объектами и запускает её. Камера управляется клавиатурой."""
